<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=lt
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'ĮTERPTI DOKUMENTĄ', # MODIF
	'bouton_ajouter_image' => 'ĮTERPTI NUOTRAUKĄ', # MODIF

	// E
	'entree_titre_document' => 'Dokumento pavadinimas :',
	'entree_titre_image' => 'Paveiksliuko pavadinimas :',

	// I
	'image_tourner_180' => '180° rotacija',
	'image_tourner_droite' => '90° rotacija į dešinę',
	'image_tourner_gauche' => '90° rotacija į kairę',
	'info_document' => 'Dokumentas',
	'info_documents' => 'Dokumentai',
	'info_inclusion_directe' => 'Tiesioginis įterpimas:',
	'info_installer_tous_documents' => 'Įterpti visus dokumentus',
	'info_logo_max_taille' => 'Logo būtinai turi būti mažiau nei @maxi@ (šis failas sudaro @actuel@).',
	'info_telecharger' => 'Atsiųsti iš jūsų kompiuterio:',

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'ZIP failas',
	'upload_fichier_zip_texte2' => 'Gal būt šis failas',
];
